@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -89,9 +87,22 @@ class ErrorHandler(object):
 
         :Raises: If the response contains an error message.
         """
-        status = response['status']
-        if status == ErrorCode.SUCCESS:
+        status = response.get('status', None)
+        if status is None or status == ErrorCode.SUCCESS:
             return
+
+        value = None
+        message = response.get("message", "")
+        screen = response.get("screen", "")
+        stacktrace = None
+        if isinstance(status, int):
+            value_json = response.get('value', None)
+            if value_json and isinstance(value_json, basestring):
+                import json
+                value = json.loads(value_json)
+                status = value['status']
+                message = value['message']
+
         exception_class = ErrorInResponseException
         if status in ErrorCode.NO_SUCH_ELEMENT:
             exception_class = NoSuchElementException
